# Brat Parser

This library parses brat's ann files and extracts Entities, Relations, Attributes, and Groups

```python
from brat_parser import get_entities_relations_attributes_groups

entities, relations, attributes, groups = get_entities_relations_attributes_groups("/path/to/ann/file.ann")
```
